==> haskell-hw-hspec-hedgehog-0.1.1.1-166-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hw-hspec-hedgehog.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hw-hspec-hedgehog
version:              0.1.1.1
visibility:           public
id:                   hw-hspec-hedgehog-0.1.1.1-3nBC7aVlSrwBmEI1rjl58h
key:                  hw-hspec-hedgehog-0.1.1.1-3nBC7aVlSrwBmEI1rjl58h
license:              BSD-3-Clause
copyright:            2017-2021 John Ky
maintainer:           newhoggy@gmail.com
author:               John Ky
homepage:             https://github.com/haskell-works/hw-hspec-hedgehog#readme
synopsis:             Interoperability between hspec and hedgehog
description:          Interoperability between hspec and hedgehog.
category:             Test
abi:                  d2fd9d06baef56622f35b679aa4a119b
exposed:              True
exposed-modules:      HaskellWorks.Hspec.Hedgehog
hidden-modules:       Paths_hw_hspec_hedgehog
import-dirs:          /usr/lib/ghc-9.4.8/site-local/hw-hspec-hedgehog-0.1.1.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hw-hspec-hedgehog-0.1.1.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hw-hspec-hedgehog-0.1.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hw-hspec-hedgehog
hs-libraries:         HShw-hspec-hedgehog-0.1.1.1-3nBC7aVlSrwBmEI1rjl58h
depends:
    HUnit-1.6.2.0-DUvlqmsw2Kp6tCDRl9WtXA base-4.17.2.1
    call-stack-0.4.0-AAQ0PbHtRxA9hkeprsdCAo
    hedgehog-1.4-JfSwdUZD2uhKeXPwmyG6lH
    hspec-2.11.0-K8tcbr0GnRpK6pvhVGiGEM transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-hw-hspec-hedgehog/html/hw-hspec-hedgehog.haddock

haddock-html:         /usr/share/doc/haskell-hw-hspec-hedgehog/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hw-hspec-hedgehog-0.1.1.1-167-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hw-hspec-hedgehog.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hw-hspec-hedgehog
version:              0.1.1.1
visibility:           public
id:                   hw-hspec-hedgehog-0.1.1.1-6kWV4Q2c7va14NU3xy5Vid
key:                  hw-hspec-hedgehog-0.1.1.1-6kWV4Q2c7va14NU3xy5Vid
license:              BSD-3-Clause
copyright:            2017-2021 John Ky
maintainer:           newhoggy@gmail.com
author:               John Ky
homepage:             https://github.com/haskell-works/hw-hspec-hedgehog#readme
synopsis:             Interoperability between hspec and hedgehog
description:          Interoperability between hspec and hedgehog.
category:             Test
abi:                  b71a8822d749a58eaf582d04a8abf229
exposed:              True
exposed-modules:      HaskellWorks.Hspec.Hedgehog
hidden-modules:       Paths_hw_hspec_hedgehog
import-dirs:          /usr/lib/ghc-9.4.8/site-local/hw-hspec-hedgehog-0.1.1.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hw-hspec-hedgehog-0.1.1.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hw-hspec-hedgehog-0.1.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hw-hspec-hedgehog
hs-libraries:         HShw-hspec-hedgehog-0.1.1.1-6kWV4Q2c7va14NU3xy5Vid
depends:
    HUnit-1.6.2.0-GnO9wO3IZ0dFnUT6z8aFmA base-4.17.2.1
    call-stack-0.4.0-GLZYnk9HL8J8EgKDjlcntK
    hedgehog-1.4-3y6692yFfF1BVcBKM4SFOn
    hspec-2.11.0-GDE5YfNyetgJEJMppTexrW transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-hw-hspec-hedgehog/html/hw-hspec-hedgehog.haddock

haddock-html:         /usr/share/doc/haskell-hw-hspec-hedgehog/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
